@@ -50,6 +50,8 @@ Further updates:
 
 =item * version 0.97, published on October 23, 2006
 
+=item * version 0.98, published on October 30, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -1554,6 +1556,7 @@ ELIJAH
 ELISA
 ELIZABETH
 ELLIOTF
+ELLIOTJS
 ELLIOTT
 ELLIPSE
 ELMAR
@@ -2575,6 +2578,7 @@ JONASO
 JONATHAN
 JONB
 JONBJ
+JONBROWN
 JONE
 JONG
 JONIONS
@@ -2729,6 +2733,7 @@ KAHUNA
 KAIH
 KAILI
 KAKE
+KALEL
 KALELE
 KALIGUS
 KALLEWOOF
@@ -2777,6 +2782,7 @@ KCODY
 KCOWGILL
 KDOULEPOV
 KDOWNEY
+KEISUKE
 KEJOKI
 KELLAN
 KEN
@@ -3818,6 +3824,7 @@ OSTROM
 OTAKA
 OTAYLOR
 OTISG
+OTTO
 OUBIWANN
 OUEST
 OVID
@@ -4433,6 +4440,7 @@ RVSUTHERL
 RWAHBY
 RWALKER
 RWENNER
+RWG
 RWKST
 RWMJ
 RWS
@@ -4571,6 +4579,7 @@ SELKOVJR
 SEMANTICO
 SEMM
 SEN
+SENDU
 SENGER
 SENSEI
 SEPH
@@ -4952,6 +4961,7 @@ TAIY
 TAKASHI
 TAKAYUKI
 TAKEFUMI
+TAKEO
 TAKESAKO
 TAKESHIGE
 TALE
@@ -5167,6 +5177,7 @@ TSTANLEY
 TSTAPFF
 TSTOCK
 TSUKAMOTO
+TSUNODA
 TSV
 TTAR
 TTOD
@@ -5260,6 +5271,7 @@ VIOSCA
 VIPERCODE
 VIPUL
 VIPULG
+VITA
 VITROTH
 VIY
 VIZDOM
