@@ -1,7 +1,7 @@
 package Acme::MetaSyntactic::yapc;
 use strict;
-use Acme::MetaSyntactic::List;
-our @ISA = qw( Acme::MetaSyntactic::List );
+use Acme::MetaSyntactic::MultiList;
+our @ISA = qw( Acme::MetaSyntactic::MultiList );
 __PACKAGE__->init();
 1;
 
@@ -41,7 +41,7 @@ Ottawa (2003).
 
 =item YAPC::Australia
 
-Melbourne (2004, 2005).
+Melbourne (2004, 2005, 2006).
 
 =item YAPC::Taipei
 
@@ -53,7 +53,11 @@ Porto Alegre (2005).
 
 =item YAPC::Asia
 
-Tokyo (2006).
+Tokyo (2006, 2007).
+
+=item YAPC::America::South
+
+São Paulo (2006).
 
 =back
 
@@ -71,20 +75,34 @@ Updated in version 0.59, published on January 30, 2006.
 
 Updated with the YAPC for 2007 in version 0.90, published on September 4, 2006.
 
+Updated with several other 2006 and 2007 YAPC, and turned into a
+MultiList by Abigail in version 0.91, published on September 11, 2006.
+
 =head1 SEE ALSO
 
-L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
+L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::MultiList>.
 
 =cut
 
 __DATA__
-# names
+# default
+:all
+# names america north
 Pittsburgh Montreal Saint_Louis Boca_Raton Buffalo Toronto Chicago Houston
+# names europe
 London Amsterdam Munich Paris Belfast Braga Birmingham Vienna
+# names israel
 Haifa Herzliya Netanya
+# names canada
 Ottawa
+# names australia
 Melbourne
+# names taipei
 Tai_Pei
+# names brazil
 Porto_Alegre
+# names asia
 Tokyo
+# names america south
+Sao_Paulo
 
